Name: libiconv
Version: 1.14
Release: 5
License: GPL-3.0-or-later
Summary: GNU iconv library
Url: https://www.gnu.org/software/libiconv

BuildRequires: libtool
BuildRequires: pase-build-tools

Source0: https://ftp.gnu.org/pub/gnu/libiconv/libiconv-%{version}.tar.gz

Patch0: libiconv-lib_Makefile.in.patch

%description
This library provides an iconv() implementation, for use on systems which don't
have one, or whose implementation cannot convert from/to Unicode.

%package -n libiconv2
Summary: GNU iconv library
License: LGPL-2.0-or-later
Provides: %{name} = %{version}
Requires: charset-alias = %{version}-%{release}

%description -n libiconv2
Provides GNU libiconv library


%package -n iconv-gnu
Summary: GNU iconv utility
License: GPL-3.0-or-later
Requires: %{name} = %{version}-%{release}

%description -n iconv-gnu
Provides the iconv program to convert files from the command line.


%package devel
Summary: GNU iconv library
License: LGPL-2.0-or-later
Requires: %{name} = %{version}-%{release}

%description devel
Provides development headers for libiconv


%package -n charset-alias
Summary: Charset alias definitions
License: LGPL-2.0-or-later

%description -n charset-alias
Provides charset.alias definitions used by several GNU packages


%prep
%setup -q

%patch0 -p1

%build

%if %{with reconf}
autoreconf -fi
%endif

%if %{without reconf}
  %define _host powerpc-ibm-aix6
%endif

%configure \
  LDFLAGS="-Wl,-brtl -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib -L%{_libdir}" \
%if %{with svr4_support}
  --with-aix-soname=svr4 \
%endif
  --disable-static \
  --disable-nls \
  --disable-rpath \
  # end

# This makes libtool build svr4 binaries somehow :)
LIBTOOL=`which libtool`
for f in `find . -name libtool`
do
  mv $f $f.bak
  ln -s $LIBTOOL $f
done

%make_build


%install

%make_install

# Header files used to be delivered in %{_includedir}/libiconv/ to opt-in to 
# using libiconv over the the system libiconv, and some packages were built
# against the header files in that location.
# These symlinks are provided so existing packages don't break.
mkdir -p %{buildroot}/%{_includedir}/libiconv
cd %{buildroot}/%{_includedir}/libiconv
ln -s ../iconv.h iconv.h
ln -s ../libcharset.h libcharset.h
ln -s ../localcharset.h localcharset.h

fix-rpath %{buildroot}/%{_bindir}/iconv %{_libdir}:/QOpenSys/usr/lib

%files -n iconv-gnu
%defattr(-, qsys, *none)

%{_bindir}/iconv

%{_mandir}/man1/iconv.1*

%files -n libiconv2
%defattr(-, qsys, *none)

%{_libdir}/libcharset.so.*
%{_libdir}/libiconv.so.*

%{_docdir}/libiconv

%files devel
%defattr(-, qsys, *none)

%{_includedir}/iconv.h
%{_includedir}/libcharset.h
%{_includedir}/localcharset.h

# Maintained so existing packages don't break
%dir %{_includedir}/libiconv
%{_includedir}/libiconv/iconv.h
%{_includedir}/libiconv/libcharset.h
%{_includedir}/libiconv/localcharset.h

%{_libdir}/libcharset.so
%{_libdir}/libiconv.so

%{_mandir}/man3/iconv.3*
%{_mandir}/man3/iconv_close.3*
%{_mandir}/man3/iconv_open.3*
%{_mandir}/man3/iconv_open_into.3*
%{_mandir}/man3/iconvctl.3*

%files -n charset-alias
%defattr(-, qsys, *none)

%{_libdir}/charset.alias


%changelog
* Tue Nov 30 2021 Mark Irish <mirish@ibm.com> - 1.14
- Split charset.alias into its own package

* Thu Nov 4 2021 Jason Hansen <stymie@us.ibm.com> - 1.14
- Intra-package Requires need version and release

* Wed Nov 18 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 1.14
- Use brp-rm-libtool-files

* Wed May 27 2020 Kevin Adler <kadler@us.ibm.com> - 1.14
- Use generic paths for man and info pages to allow for compression

* Fri Apr 10 2020 Mark Irish <mirish@ibm.com> - 1.14
- Move header files to /include, but keep symlinks for compatability

* Tue Nov 19 2019 Kevin Adler <kadler@us.ibm.com> - 1.14
- Use SPDX license identifier

* Tue Mar 26 2019 Kevin Adler <kadler@us.ibm.com> - 1.14
- ibm-build-tools -> pase-build-tools

* Fri Jun 08 2018 - Kevin Adler <kadler@us.ibm.com>
- Hack to work around bad LIBPATH in iconv binary

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Remove gcc wrappers
- Add BuildRequires
- various other fixes

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Make libiconv build svr4 library

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Use auto dependency resolution instead of requiring pase-libs

* Tue Nov 07 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix license

* Thu Aug 24 2017 - Kevin Adler <kadler@us.ibm.com>
- Add missing defattr(-, qsys, *none)
